# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from collections import OrderedDict
import functools
import re
from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
import pkg_resources

from google.api_core.client_options import ClientOptions
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

try:
    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
except AttributeError:  # pragma: NO COVER
    OptionalRetry = Union[retries.Retry, object]  # type: ignore

from google.cloud.speech_v1.services.adaptation import pagers
from google.cloud.speech_v1.types import cloud_speech_adaptation
from google.cloud.speech_v1.types import resource
from google.protobuf import field_mask_pb2  # type: ignore
from .transports.base import AdaptationTransport, DEFAULT_CLIENT_INFO
from .transports.grpc_asyncio import AdaptationGrpcAsyncIOTransport
from .client import AdaptationClient


class AdaptationAsyncClient:
    """Service that implements Google Cloud Speech Adaptation API."""

    _client: AdaptationClient

    DEFAULT_ENDPOINT = AdaptationClient.DEFAULT_ENDPOINT
    DEFAULT_MTLS_ENDPOINT = AdaptationClient.DEFAULT_MTLS_ENDPOINT

    custom_class_path = staticmethod(AdaptationClient.custom_class_path)
    parse_custom_class_path = staticmethod(AdaptationClient.parse_custom_class_path)
    phrase_set_path = staticmethod(AdaptationClient.phrase_set_path)
    parse_phrase_set_path = staticmethod(AdaptationClient.parse_phrase_set_path)
    common_billing_account_path = staticmethod(
        AdaptationClient.common_billing_account_path
    )
    parse_common_billing_account_path = staticmethod(
        AdaptationClient.parse_common_billing_account_path
    )
    common_folder_path = staticmethod(AdaptationClient.common_folder_path)
    parse_common_folder_path = staticmethod(AdaptationClient.parse_common_folder_path)
    common_organization_path = staticmethod(AdaptationClient.common_organization_path)
    parse_common_organization_path = staticmethod(
        AdaptationClient.parse_common_organization_path
    )
    common_project_path = staticmethod(AdaptationClient.common_project_path)
    parse_common_project_path = staticmethod(AdaptationClient.parse_common_project_path)
    common_location_path = staticmethod(AdaptationClient.common_location_path)
    parse_common_location_path = staticmethod(
        AdaptationClient.parse_common_location_path
    )

    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            info.

        Args:
            info (dict): The service account private key info.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            AdaptationAsyncClient: The constructed client.
        """
        return AdaptationClient.from_service_account_info.__func__(AdaptationAsyncClient, info, *args, **kwargs)  # type: ignore

    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
            file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            AdaptationAsyncClient: The constructed client.
        """
        return AdaptationClient.from_service_account_file.__func__(AdaptationAsyncClient, filename, *args, **kwargs)  # type: ignore

    from_service_account_json = from_service_account_file

    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: Optional[ClientOptions] = None
    ):
        """Return the API endpoint and client cert source for mutual TLS.

        The client cert source is determined in the following order:
        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
        client cert source is None.
        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
        default client cert source exists, use the default one; otherwise the client cert
        source is None.

        The API endpoint is determined in the following order:
        (1) if `client_options.api_endpoint` if provided, use the provided one.
        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
        default mTLS endpoint; if the environment variabel is "never", use the default API
        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
        use the default API endpoint.

        More details can be found at https://google.aip.dev/auth/4114.

        Args:
            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                client. Only the `api_endpoint` and `client_cert_source` properties may be used
                in this method.

        Returns:
            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
                client cert source to use.

        Raises:
            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
        """
        return AdaptationClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore

    @property
    def transport(self) -> AdaptationTransport:
        """Returns the transport used by the client instance.

        Returns:
            AdaptationTransport: The transport used by the client instance.
        """
        return self._client.transport

    get_transport_class = functools.partial(
        type(AdaptationClient).get_transport_class, type(AdaptationClient)
    )

    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials = None,
        transport: Union[str, AdaptationTransport] = "grpc_asyncio",
        client_options: ClientOptions = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
    ) -> None:
        """Instantiates the adaptation client.

        Args:
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            transport (Union[str, ~.AdaptationTransport]): The
                transport to use. If set to None, a transport is chosen
                automatically.
            client_options (ClientOptions): Custom options for the client. It
                won't take effect if a ``transport`` instance is provided.
                (1) The ``api_endpoint`` property can be used to override the
                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                environment variable can also be used to override the endpoint:
                "always" (always use the default mTLS endpoint), "never" (always
                use the default regular endpoint) and "auto" (auto switch to the
                default mTLS endpoint if client certificate is present, this is
                the default value). However, the ``api_endpoint`` property takes
                precedence if provided.
                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
                is "true", then the ``client_cert_source`` property can be used
                to provide client certificate for mutual TLS transport. If
                not provided, the default SSL client certificate will be used if
                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
                set, no client certificate will be used.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                creation failed for any reason.
        """
        self._client = AdaptationClient(
            credentials=credentials,
            transport=transport,
            client_options=client_options,
            client_info=client_info,
        )

    async def create_phrase_set(
        self,
        request: Union[cloud_speech_adaptation.CreatePhraseSetRequest, dict] = None,
        *,
        parent: str = None,
        phrase_set: resource.PhraseSet = None,
        phrase_set_id: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> resource.PhraseSet:
        r"""Create a set of phrase hints. Each item in the set
        can be a single word or a multi-word phrase. The items
        in the PhraseSet are favored by the recognition model
        when you send a call that includes the PhraseSet.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_create_phrase_set():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.CreatePhraseSetRequest(
                    parent="parent_value",
                    phrase_set_id="phrase_set_id_value",
                )

                # Make the request
                response = await client.create_phrase_set(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.CreatePhraseSetRequest, dict]):
                The request object. Message sent by the client for the
                `CreatePhraseSet` method.
            parent (:class:`str`):
                Required. The parent resource where this phrase set will
                be created. Format:

                ``projects/{project}/locations/{location}/phraseSets``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            phrase_set (:class:`google.cloud.speech_v1.types.PhraseSet`):
                Required. The phrase set to create.
                This corresponds to the ``phrase_set`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            phrase_set_id (:class:`str`):
                Required. The ID to use for the
                phrase set, which will become the final
                component of the phrase set's resource
                name.
                This value should restrict to letters,
                numbers, and hyphens, with the first
                character a letter, the last a letter or
                a number, and be 4-63 characters.

                This corresponds to the ``phrase_set_id`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.types.PhraseSet:
                Provides "hints" to the speech
                recognizer to favor specific words and
                phrases in the results.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, phrase_set, phrase_set_id])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.CreatePhraseSetRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if phrase_set is not None:
            request.phrase_set = phrase_set
        if phrase_set_id is not None:
            request.phrase_set_id = phrase_set_id

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_phrase_set,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_phrase_set(
        self,
        request: Union[cloud_speech_adaptation.GetPhraseSetRequest, dict] = None,
        *,
        name: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> resource.PhraseSet:
        r"""Get a phrase set.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_get_phrase_set():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.GetPhraseSetRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_phrase_set(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.GetPhraseSetRequest, dict]):
                The request object. Message sent by the client for the
                `GetPhraseSet` method.
            name (:class:`str`):
                Required. The name of the phrase set to retrieve.
                Format:

                ``projects/{project}/locations/{location}/phraseSets/{phrase_set}``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.types.PhraseSet:
                Provides "hints" to the speech
                recognizer to favor specific words and
                phrases in the results.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.GetPhraseSetRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_phrase_set,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_phrase_set(
        self,
        request: Union[cloud_speech_adaptation.ListPhraseSetRequest, dict] = None,
        *,
        parent: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.ListPhraseSetAsyncPager:
        r"""List phrase sets.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_list_phrase_set():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.ListPhraseSetRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_phrase_set(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.ListPhraseSetRequest, dict]):
                The request object. Message sent by the client for the
                `ListPhraseSet` method.
            parent (:class:`str`):
                Required. The parent, which owns this collection of
                phrase set. Format:

                ``projects/{project}/locations/{location}``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.services.adaptation.pagers.ListPhraseSetAsyncPager:
                Message returned to the client by the ListPhraseSet
                method.

                Iterating over this object will yield results and
                resolve additional pages automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.ListPhraseSetRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_phrase_set,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListPhraseSetAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def update_phrase_set(
        self,
        request: Union[cloud_speech_adaptation.UpdatePhraseSetRequest, dict] = None,
        *,
        phrase_set: resource.PhraseSet = None,
        update_mask: field_mask_pb2.FieldMask = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> resource.PhraseSet:
        r"""Update a phrase set.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_update_phrase_set():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.UpdatePhraseSetRequest(
                )

                # Make the request
                response = await client.update_phrase_set(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.UpdatePhraseSetRequest, dict]):
                The request object. Message sent by the client for the
                `UpdatePhraseSet` method.
            phrase_set (:class:`google.cloud.speech_v1.types.PhraseSet`):
                Required. The phrase set to update.

                The phrase set's ``name`` field is used to identify the
                set to be updated. Format:

                ``projects/{project}/locations/{location}/phraseSets/{phrase_set}``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``phrase_set`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                The list of fields to be updated.
                This corresponds to the ``update_mask`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.types.PhraseSet:
                Provides "hints" to the speech
                recognizer to favor specific words and
                phrases in the results.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([phrase_set, update_mask])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.UpdatePhraseSetRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if phrase_set is not None:
            request.phrase_set = phrase_set
        if update_mask is not None:
            request.update_mask = update_mask

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.update_phrase_set,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata(
                (("phrase_set.name", request.phrase_set.name),)
            ),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_phrase_set(
        self,
        request: Union[cloud_speech_adaptation.DeletePhraseSetRequest, dict] = None,
        *,
        name: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Delete a phrase set.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_delete_phrase_set():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.DeletePhraseSetRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_phrase_set(request=request)

        Args:
            request (Union[google.cloud.speech_v1.types.DeletePhraseSetRequest, dict]):
                The request object. Message sent by the client for the
                `DeletePhraseSet` method.
            name (:class:`str`):
                Required. The name of the phrase set to delete. Format:

                ``projects/{project}/locations/{location}/phraseSets/{phrase_set}``

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.DeletePhraseSetRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_phrase_set,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def create_custom_class(
        self,
        request: Union[cloud_speech_adaptation.CreateCustomClassRequest, dict] = None,
        *,
        parent: str = None,
        custom_class: resource.CustomClass = None,
        custom_class_id: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> resource.CustomClass:
        r"""Create a custom class.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_create_custom_class():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.CreateCustomClassRequest(
                    parent="parent_value",
                    custom_class_id="custom_class_id_value",
                )

                # Make the request
                response = await client.create_custom_class(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.CreateCustomClassRequest, dict]):
                The request object. Message sent by the client for the
                `CreateCustomClass` method.
            parent (:class:`str`):
                Required. The parent resource where this custom class
                will be created. Format:

                ``projects/{project}/locations/{location}/customClasses``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            custom_class (:class:`google.cloud.speech_v1.types.CustomClass`):
                Required. The custom class to create.
                This corresponds to the ``custom_class`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            custom_class_id (:class:`str`):
                Required. The ID to use for the
                custom class, which will become the
                final component of the custom class'
                resource name.
                This value should restrict to letters,
                numbers, and hyphens, with the first
                character a letter, the last a letter or
                a number, and be 4-63 characters.

                This corresponds to the ``custom_class_id`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.types.CustomClass:
                A set of words or phrases that
                represents a common concept likely to
                appear in your audio, for example a list
                of passenger ship names. CustomClass
                items can be substituted into
                placeholders that you set in PhraseSet
                phrases.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent, custom_class, custom_class_id])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.CreateCustomClassRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent
        if custom_class is not None:
            request.custom_class = custom_class
        if custom_class_id is not None:
            request.custom_class_id = custom_class_id

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.create_custom_class,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def get_custom_class(
        self,
        request: Union[cloud_speech_adaptation.GetCustomClassRequest, dict] = None,
        *,
        name: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> resource.CustomClass:
        r"""Get a custom class.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_get_custom_class():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.GetCustomClassRequest(
                    name="name_value",
                )

                # Make the request
                response = await client.get_custom_class(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.GetCustomClassRequest, dict]):
                The request object. Message sent by the client for the
                `GetCustomClass` method.
            name (:class:`str`):
                Required. The name of the custom class to retrieve.
                Format:

                ``projects/{project}/locations/{location}/customClasses/{custom_class}``

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.types.CustomClass:
                A set of words or phrases that
                represents a common concept likely to
                appear in your audio, for example a list
                of passenger ship names. CustomClass
                items can be substituted into
                placeholders that you set in PhraseSet
                phrases.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.GetCustomClassRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.get_custom_class,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def list_custom_classes(
        self,
        request: Union[cloud_speech_adaptation.ListCustomClassesRequest, dict] = None,
        *,
        parent: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> pagers.ListCustomClassesAsyncPager:
        r"""List custom classes.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_list_custom_classes():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.ListCustomClassesRequest(
                    parent="parent_value",
                )

                # Make the request
                page_result = client.list_custom_classes(request=request)

                # Handle the response
                async for response in page_result:
                    print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.ListCustomClassesRequest, dict]):
                The request object. Message sent by the client for the
                `ListCustomClasses` method.
            parent (:class:`str`):
                Required. The parent, which owns this collection of
                custom classes. Format:

                ``projects/{project}/locations/{location}/customClasses``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``parent`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.services.adaptation.pagers.ListCustomClassesAsyncPager:
                Message returned to the client by the ListCustomClasses
                method.

                Iterating over this object will yield results and
                resolve additional pages automatically.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([parent])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.ListCustomClassesRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if parent is not None:
            request.parent = parent

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.list_custom_classes,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("parent", request.parent),)),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # This method is paged; wrap the response in a pager, which provides
        # an `__aiter__` convenience method.
        response = pagers.ListCustomClassesAsyncPager(
            method=rpc,
            request=request,
            response=response,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def update_custom_class(
        self,
        request: Union[cloud_speech_adaptation.UpdateCustomClassRequest, dict] = None,
        *,
        custom_class: resource.CustomClass = None,
        update_mask: field_mask_pb2.FieldMask = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> resource.CustomClass:
        r"""Update a custom class.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_update_custom_class():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.UpdateCustomClassRequest(
                )

                # Make the request
                response = await client.update_custom_class(request=request)

                # Handle the response
                print(response)

        Args:
            request (Union[google.cloud.speech_v1.types.UpdateCustomClassRequest, dict]):
                The request object. Message sent by the client for the
                `UpdateCustomClass` method.
            custom_class (:class:`google.cloud.speech_v1.types.CustomClass`):
                Required. The custom class to update.

                The custom class's ``name`` field is used to identify
                the custom class to be updated. Format:

                ``projects/{project}/locations/{location}/customClasses/{custom_class}``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``custom_class`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
                The list of fields to be updated.
                This corresponds to the ``update_mask`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
            google.cloud.speech_v1.types.CustomClass:
                A set of words or phrases that
                represents a common concept likely to
                appear in your audio, for example a list
                of passenger ship names. CustomClass
                items can be substituted into
                placeholders that you set in PhraseSet
                phrases.

        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([custom_class, update_mask])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.UpdateCustomClassRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if custom_class is not None:
            request.custom_class = custom_class
        if update_mask is not None:
            request.update_mask = update_mask

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.update_custom_class,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata(
                (("custom_class.name", request.custom_class.name),)
            ),
        )

        # Send the request.
        response = await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

        # Done; return the response.
        return response

    async def delete_custom_class(
        self,
        request: Union[cloud_speech_adaptation.DeleteCustomClassRequest, dict] = None,
        *,
        name: str = None,
        retry: OptionalRetry = gapic_v1.method.DEFAULT,
        timeout: float = None,
        metadata: Sequence[Tuple[str, str]] = (),
    ) -> None:
        r"""Delete a custom class.

        .. code-block:: python

            # This snippet has been automatically generated and should be regarded as a
            # code template only.
            # It will require modifications to work:
            # - It may require correct/in-range values for request initialization.
            # - It may require specifying regional endpoints when creating the service
            #   client as shown in:
            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
            from google.cloud import speech_v1

            async def sample_delete_custom_class():
                # Create a client
                client = speech_v1.AdaptationAsyncClient()

                # Initialize request argument(s)
                request = speech_v1.DeleteCustomClassRequest(
                    name="name_value",
                )

                # Make the request
                await client.delete_custom_class(request=request)

        Args:
            request (Union[google.cloud.speech_v1.types.DeleteCustomClassRequest, dict]):
                The request object. Message sent by the client for the
                `DeleteCustomClass` method.
            name (:class:`str`):
                Required. The name of the custom class to delete.
                Format:

                ``projects/{project}/locations/{location}/customClasses/{custom_class}``

                Speech-to-Text supports three locations: ``global``,
                ``us`` (US North America), and ``eu`` (Europe). If you
                are calling the ``speech.googleapis.com`` endpoint, use
                the ``global`` location. To specify a region, use a
                `regional
                endpoint <https://cloud.google.com/speech-to-text/docs/endpoints>`__
                with matching ``us`` or ``eu`` location value.

                This corresponds to the ``name`` field
                on the ``request`` instance; if ``request`` is provided, this
                should not be set.
            retry (google.api_core.retry.Retry): Designation of what errors, if any,
                should be retried.
            timeout (float): The timeout for this request.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        # Create or coerce a protobuf request object.
        # Quick check: If we got a request object, we should *not* have
        # gotten any keyword arguments that map to the request.
        has_flattened_params = any([name])
        if request is not None and has_flattened_params:
            raise ValueError(
                "If the `request` argument is set, then none of "
                "the individual field arguments should be set."
            )

        request = cloud_speech_adaptation.DeleteCustomClassRequest(request)

        # If we have keyword arguments corresponding to fields on the
        # request, apply these.
        if name is not None:
            request.name = name

        # Wrap the RPC method; this adds retry and timeout information,
        # and friendly error handling.
        rpc = gapic_v1.method_async.wrap_method(
            self._client._transport.delete_custom_class,
            default_timeout=None,
            client_info=DEFAULT_CLIENT_INFO,
        )

        # Certain fields should be provided within the metadata header;
        # add these here.
        metadata = tuple(metadata) + (
            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
        )

        # Send the request.
        await rpc(
            request,
            retry=retry,
            timeout=timeout,
            metadata=metadata,
        )

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc, tb):
        await self.transport.close()


try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-speech",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


__all__ = ("AdaptationAsyncClient",)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloud_speech import (
    AutoDetectDecodingConfig,
    BatchRecognizeFileMetadata,
    BatchRecognizeFileResult,
    BatchRecognizeMetadata,
    BatchRecognizeRequest,
    BatchRecognizeResponse,
    BatchRecognizeTranscriptionMetadata,
    Config,
    CreateCustomClassRequest,
    CreatePhraseSetRequest,
    CreateRecognizerRequest,
    CustomClass,
    DeleteCustomClassRequest,
    DeletePhraseSetRequest,
    DeleteRecognizerRequest,
    ExplicitDecodingConfig,
    GetConfigRequest,
    GetCustomClassRequest,
    GetPhraseSetRequest,
    GetRecognizerRequest,
    ListCustomClassesRequest,
    ListCustomClassesResponse,
    ListPhraseSetsRequest,
    ListPhraseSetsResponse,
    ListRecognizersRequest,
    ListRecognizersResponse,
    OperationMetadata,
    PhraseSet,
    RecognitionConfig,
    RecognitionFeatures,
    RecognitionResponseMetadata,
    Recognizer,
    RecognizeRequest,
    RecognizeResponse,
    SpeakerDiarizationConfig,
    SpeechAdaptation,
    SpeechRecognitionAlternative,
    SpeechRecognitionResult,
    StreamingRecognitionConfig,
    StreamingRecognitionFeatures,
    StreamingRecognitionResult,
    StreamingRecognizeRequest,
    StreamingRecognizeResponse,
    UndeleteCustomClassRequest,
    UndeletePhraseSetRequest,
    UndeleteRecognizerRequest,
    UpdateConfigRequest,
    UpdateCustomClassRequest,
    UpdatePhraseSetRequest,
    UpdateRecognizerRequest,
    WordInfo,
)

__all__ = (
    "AutoDetectDecodingConfig",
    "BatchRecognizeFileMetadata",
    "BatchRecognizeFileResult",
    "BatchRecognizeMetadata",
    "BatchRecognizeRequest",
    "BatchRecognizeResponse",
    "BatchRecognizeTranscriptionMetadata",
    "Config",
    "CreateCustomClassRequest",
    "CreatePhraseSetRequest",
    "CreateRecognizerRequest",
    "CustomClass",
    "DeleteCustomClassRequest",
    "DeletePhraseSetRequest",
    "DeleteRecognizerRequest",
    "ExplicitDecodingConfig",
    "GetConfigRequest",
    "GetCustomClassRequest",
    "GetPhraseSetRequest",
    "GetRecognizerRequest",
    "ListCustomClassesRequest",
    "ListCustomClassesResponse",
    "ListPhraseSetsRequest",
    "ListPhraseSetsResponse",
    "ListRecognizersRequest",
    "ListRecognizersResponse",
    "OperationMetadata",
    "PhraseSet",
    "RecognitionConfig",
    "RecognitionFeatures",
    "RecognitionResponseMetadata",
    "Recognizer",
    "RecognizeRequest",
    "RecognizeResponse",
    "SpeakerDiarizationConfig",
    "SpeechAdaptation",
    "SpeechRecognitionAlternative",
    "SpeechRecognitionResult",
    "StreamingRecognitionConfig",
    "StreamingRecognitionFeatures",
    "StreamingRecognitionResult",
    "StreamingRecognizeRequest",
    "StreamingRecognizeResponse",
    "UndeleteCustomClassRequest",
    "UndeletePhraseSetRequest",
    "UndeleteRecognizerRequest",
    "UpdateConfigRequest",
    "UpdateCustomClassRequest",
    "UpdatePhraseSetRequest",
    "UpdateRecognizerRequest",
    "WordInfo",
)



# Copyright 2017, Google LLC All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import

import google.api_core.gapic_v1.method


class SpeechHelpers(object):
    """A set of convenience methods to make the Speech client easier to use.

    This class should be considered abstract; it is used as a superclass
    in a multiple-inheritance construction alongside the applicable GAPIC.
    See the :class:`~google.cloud.speech_v1.SpeechClient`.
    """

    def streaming_recognize(
        self,
        config,
        requests,
        *,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=(),
    ):
        """Perform bi-directional speech recognition.

        This method allows you to receive results while sending audio;
        it is only available via. gRPC (not REST).

        .. warning::

            This method is EXPERIMENTAL. Its interface might change in the
            future.

        Example:
          >>> from google.cloud import speech_v1
          >>> client = speech_v1.SpeechClient()
          >>> config = speech_v1.StreamingRecognitionConfig(
          ...     config=speech_v1.RecognitionConfig(
          ...         encoding=speech_v1.RecognitionConfig.AudioEncoding.FLAC,
          ...     ),
          ... )
          >>> request = speech_v1.StreamingRecognizeRequest(audio_content=b'...')
          >>> requests = [request]
          >>> for element in client.streaming_recognize(config, requests):
          ...     # process element
          ...     pass

        Args:
            config (:class:`~.types.StreamingRecognitionConfig`): The
                configuration to use for the stream.
            requests (Iterable[:class:`~.types.StreamingRecognizeRequest`]):
                The input objects.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.

        Returns:
          Iterable[:class:`~.types.StreamingRecognizeResponse`]

        Raises:
          :exc:`ValueError` if the parameters are invalid.
        """
        return super(SpeechHelpers, self).streaming_recognize(
            requests=self._streaming_request_iterable(config, requests),
            retry=retry,
            timeout=timeout,
        )

    def _streaming_request_iterable(self, config, requests):
        """A generator that yields the config followed by the requests.

        Args:
            config (~.speech_v1.types.StreamingRecognitionConfig): The
                configuration to use for the stream.
            requests (Iterable[~.speech_v1.types.StreamingRecognizeRequest]):
                The input objects.

        Returns:
            Iterable[~.speech_v1.types.StreamingRecognizeRequest]): The
                correctly formatted input for
                :meth:`~.speech_v1.SpeechClient.streaming_recognize`.
        """
        # yield a dictionary rather than the request object since the helper
        # is used by both the v1 and v1p1beta1
        yield {"streaming_config": config}
        for request in requests:
            yield request



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.speech_v1p1beta1.types import resource
from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
from google.protobuf import wrappers_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.speech.v1p1beta1",
    manifest={
        "RecognizeRequest",
        "LongRunningRecognizeRequest",
        "TranscriptOutputConfig",
        "StreamingRecognizeRequest",
        "StreamingRecognitionConfig",
        "RecognitionConfig",
        "SpeakerDiarizationConfig",
        "RecognitionMetadata",
        "SpeechContext",
        "RecognitionAudio",
        "RecognizeResponse",
        "LongRunningRecognizeResponse",
        "LongRunningRecognizeMetadata",
        "StreamingRecognizeResponse",
        "StreamingRecognitionResult",
        "SpeechRecognitionResult",
        "SpeechRecognitionAlternative",
        "WordInfo",
    },
)


class RecognizeRequest(proto.Message):
    r"""The top-level message sent by the client for the ``Recognize``
    method.

    Attributes:
        config (google.cloud.speech_v1p1beta1.types.RecognitionConfig):
            Required. Provides information to the
            recognizer that specifies how to process the
            request.
        audio (google.cloud.speech_v1p1beta1.types.RecognitionAudio):
            Required. The audio data to be recognized.
    """

    config = proto.Field(
        proto.MESSAGE,
        number=1,
        message="RecognitionConfig",
    )
    audio = proto.Field(
        proto.MESSAGE,
        number=2,
        message="RecognitionAudio",
    )


class LongRunningRecognizeRequest(proto.Message):
    r"""The top-level message sent by the client for the
    ``LongRunningRecognize`` method.

    Attributes:
        config (google.cloud.speech_v1p1beta1.types.RecognitionConfig):
            Required. Provides information to the
            recognizer that specifies how to process the
            request.
        audio (google.cloud.speech_v1p1beta1.types.RecognitionAudio):
            Required. The audio data to be recognized.
        output_config (google.cloud.speech_v1p1beta1.types.TranscriptOutputConfig):
            Optional. Specifies an optional destination
            for the recognition results.
    """

    config = proto.Field(
        proto.MESSAGE,
        number=1,
        message="RecognitionConfig",
    )
    audio = proto.Field(
        proto.MESSAGE,
        number=2,
        message="RecognitionAudio",
    )
    output_config = proto.Field(
        proto.MESSAGE,
        number=4,
        message="TranscriptOutputConfig",
    )


class TranscriptOutputConfig(proto.Message):
    r"""Specifies an optional destination for the recognition
    results.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        gcs_uri (str):
            Specifies a Cloud Storage URI for the recognition results.
            Must be specified in the format:
            ``gs://bucket_name/object_name``, and the bucket must
            already exist.

            This field is a member of `oneof`_ ``output_type``.
    """

    gcs_uri = proto.Field(
        proto.STRING,
        number=1,
        oneof="output_type",
    )


class StreamingRecognizeRequest(proto.Message):
    r"""The top-level message sent by the client for the
    ``StreamingRecognize`` method. Multiple
    ``StreamingRecognizeRequest`` messages are sent. The first message
    must contain a ``streaming_config`` message and must not contain
    ``audio_content``. All subsequent messages must contain
    ``audio_content`` and must not contain a ``streaming_config``
    message.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        streaming_config (google.cloud.speech_v1p1beta1.types.StreamingRecognitionConfig):
            Provides information to the recognizer that specifies how to
            process the request. The first ``StreamingRecognizeRequest``
            message must contain a ``streaming_config`` message.

            This field is a member of `oneof`_ ``streaming_request``.
        audio_content (bytes):
            The audio data to be recognized. Sequential chunks of audio
            data are sent in sequential ``StreamingRecognizeRequest``
            messages. The first ``StreamingRecognizeRequest`` message
            must not contain ``audio_content`` data and all subsequent
            ``StreamingRecognizeRequest`` messages must contain
            ``audio_content`` data. The audio bytes must be encoded as
            specified in ``RecognitionConfig``. Note: as with all bytes
            fields, proto buffers use a pure binary representation (not
            base64). See `content
            limits <https://cloud.google.com/speech-to-text/quotas#content>`__.

            This field is a member of `oneof`_ ``streaming_request``.
    """

    streaming_config = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="streaming_request",
        message="StreamingRecognitionConfig",
    )
    audio_content = proto.Field(
        proto.BYTES,
        number=2,
        oneof="streaming_request",
    )


class StreamingRecognitionConfig(proto.Message):
    r"""Provides information to the recognizer that specifies how to
    process the request.

    Attributes:
        config (google.cloud.speech_v1p1beta1.types.RecognitionConfig):
            Required. Provides information to the
            recognizer that specifies how to process the
            request.
        single_utterance (bool):
            If ``false`` or omitted, the recognizer will perform
            continuous recognition (continuing to wait for and process
            audio even if the user pauses speaking) until the client
            closes the input stream (gRPC API) or until the maximum time
            limit has been reached. May return multiple
            ``StreamingRecognitionResult``\ s with the ``is_final`` flag
            set to ``true``.

            If ``true``, the recognizer will detect a single spoken
            utterance. When it detects that the user has paused or
            stopped speaking, it will return an
            ``END_OF_SINGLE_UTTERANCE`` event and cease recognition. It
            will return no more than one ``StreamingRecognitionResult``
            with the ``is_final`` flag set to ``true``.

            The ``single_utterance`` field can only be used with
            specified models, otherwise an error is thrown. The
            ``model`` field in [``RecognitionConfig``][] must be set to:

            -  ``command_and_search``
            -  ``phone_call`` AND additional field
               ``useEnhanced``\ =\ ``true``
            -  The ``model`` field is left undefined. In this case the
               API auto-selects a model based on any other parameters
               that you set in ``RecognitionConfig``.
        interim_results (bool):
            If ``true``, interim results (tentative hypotheses) may be
            returned as they become available (these interim results are
            indicated with the ``is_final=false`` flag). If ``false`` or
            omitted, only ``is_final=true`` result(s) are returned.
    """

    config = proto.Field(
        proto.MESSAGE,
        number=1,
        message="RecognitionConfig",
    )
    single_utterance = proto.Field(
        proto.BOOL,
        number=2,
    )
    interim_results = proto.Field(
        proto.BOOL,
        number=3,
    )


class RecognitionConfig(proto.Message):
    r"""Provides information to the recognizer that specifies how to
    process the request.

    Attributes:
        encoding (google.cloud.speech_v1p1beta1.types.RecognitionConfig.AudioEncoding):
            Encoding of audio data sent in all ``RecognitionAudio``
            messages. This field is optional for ``FLAC`` and ``WAV``
            audio files and required for all other audio formats. For
            details, see
            [AudioEncoding][google.cloud.speech.v1p1beta1.RecognitionConfig.AudioEncoding].
        sample_rate_hertz (int):
            Sample rate in Hertz of the audio data sent in all
            ``RecognitionAudio`` messages. Valid values are: 8000-48000.
            16000 is optimal. For best results, set the sampling rate of
            the audio source to 16000 Hz. If that's not possible, use
            the native sample rate of the audio source (instead of
            re-sampling). This field is optional for FLAC and WAV audio
            files, but is required for all other audio formats. For
            details, see
            [AudioEncoding][google.cloud.speech.v1p1beta1.RecognitionConfig.AudioEncoding].
        audio_channel_count (int):
            The number of channels in the input audio data. ONLY set
            this for MULTI-CHANNEL recognition. Valid values for
            LINEAR16 and FLAC are ``1``-``8``. Valid values for OGG_OPUS
            are '1'-'254'. Valid value for MULAW, AMR, AMR_WB and
            SPEEX_WITH_HEADER_BYTE is only ``1``. If ``0`` or omitted,
            defaults to one channel (mono). Note: We only recognize the
            first channel by default. To perform independent recognition
            on each channel set
            ``enable_separate_recognition_per_channel`` to 'true'.
        enable_separate_recognition_per_channel (bool):
            This needs to be set to ``true`` explicitly and
            ``audio_channel_count`` > 1 to get each channel recognized
            separately. The recognition result will contain a
            ``channel_tag`` field to state which channel that result
            belongs to. If this is not true, we will only recognize the
            first channel. The request is billed cumulatively for all
            channels recognized: ``audio_channel_count`` multiplied by
            the length of the audio.
        language_code (str):
            Required. The language of the supplied audio as a
            `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
            language tag. Example: "en-US". See `Language
            Support <https://cloud.google.com/speech-to-text/docs/languages>`__
            for a list of the currently supported language codes.
        alternative_language_codes (Sequence[str]):
            A list of up to 3 additional
            `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
            language tags, listing possible alternative languages of the
            supplied audio. See `Language
            Support <https://cloud.google.com/speech-to-text/docs/languages>`__
            for a list of the currently supported language codes. If
            alternative languages are listed, recognition result will
            contain recognition in the most likely language detected
            including the main language_code. The recognition result
            will include the language tag of the language detected in
            the audio. Note: This feature is only supported for Voice
            Command and Voice Search use cases and performance may vary
            for other use cases (e.g., phone call transcription).
        max_alternatives (int):
            Maximum number of recognition hypotheses to be returned.
            Specifically, the maximum number of
            ``SpeechRecognitionAlternative`` messages within each
            ``SpeechRecognitionResult``. The server may return fewer
            than ``max_alternatives``. Valid values are ``0``-``30``. A
            value of ``0`` or ``1`` will return a maximum of one. If
            omitted, will return a maximum of one.
        profanity_filter (bool):
            If set to ``true``, the server will attempt to filter out
            profanities, replacing all but the initial character in each
            filtered word with asterisks, e.g. "f***". If set to
            ``false`` or omitted, profanities won't be filtered out.
        adaptation (google.cloud.speech_v1p1beta1.types.SpeechAdaptation):
            Speech adaptation configuration improves the accuracy of
            speech recognition. For more information, see the `speech
            adaptation <https://cloud.google.com/speech-to-text/docs/adaptation>`__
            documentation. When speech adaptation is set it supersedes
            the ``speech_contexts`` field.
        transcript_normalization (google.cloud.speech_v1p1beta1.types.TranscriptNormalization):
            Use transcription normalization to
            automatically replace parts of the transcript
            with phrases of your choosing. For
            StreamingRecognize, this normalization only
            applies to stable partial transcripts (stability
            > 0.8) and final transcripts.
        speech_contexts (Sequence[google.cloud.speech_v1p1beta1.types.SpeechContext]):
            Array of
            [SpeechContext][google.cloud.speech.v1p1beta1.SpeechContext].
            A means to provide context to assist the speech recognition.
            For more information, see `speech
            adaptation <https://cloud.google.com/speech-to-text/docs/adaptation>`__.
        enable_word_time_offsets (bool):
            If ``true``, the top result includes a list of words and the
            start and end time offsets (timestamps) for those words. If
            ``false``, no word-level time offset information is
            returned. The default is ``false``.
        enable_word_confidence (bool):
            If ``true``, the top result includes a list of words and the
            confidence for those words. If ``false``, no word-level
            confidence information is returned. The default is
            ``false``.
        enable_automatic_punctuation (bool):
            If 'true', adds punctuation to recognition
            result hypotheses. This feature is only
            available in select languages. Setting this for
            requests in other languages has no effect at
            all. The default 'false' value does not add
            punctuation to result hypotheses.
        enable_spoken_punctuation (google.protobuf.wrappers_pb2.BoolValue):
            The spoken punctuation behavior for the call If not set,
            uses default behavior based on model of choice e.g.
            command_and_search will enable spoken punctuation by default
            If 'true', replaces spoken punctuation with the
            corresponding symbols in the request. For example, "how are
            you question mark" becomes "how are you?". See
            https://cloud.google.com/speech-to-text/docs/spoken-punctuation
            for support. If 'false', spoken punctuation is not replaced.
        enable_spoken_emojis (google.protobuf.wrappers_pb2.BoolValue):
            The spoken emoji behavior for the call
            If not set, uses default behavior based on model
            of choice If 'true', adds spoken emoji
            formatting for the request. This will replace
            spoken emojis with the corresponding Unicode
            symbols in the final transcript. If 'false',
            spoken emojis are not replaced.
        enable_speaker_diarization (bool):
            If 'true', enables speaker detection for each recognized
            word in the top alternative of the recognition result using
            a speaker_tag provided in the WordInfo. Note: Use
            diarization_config instead.
        diarization_speaker_count (int):
            If set, specifies the estimated number of speakers in the
            conversation. Defaults to '2'. Ignored unless
            enable_speaker_diarization is set to true. Note: Use
            diarization_config instead.
        diarization_config (google.cloud.speech_v1p1beta1.types.SpeakerDiarizationConfig):
            Config to enable speaker diarization and set
            additional parameters to make diarization better
            suited for your application. Note: When this is
            enabled, we send all the words from the
            beginning of the audio for the top alternative
            in every consecutive STREAMING responses. This
            is done in order to improve our speaker tags as
            our models learn to identify the speakers in the
            conversation over time. For non-streaming
            requests, the diarization results will be
            provided only in the top alternative of the
            FINAL SpeechRecognitionResult.
        metadata (google.cloud.speech_v1p1beta1.types.RecognitionMetadata):
            Metadata regarding this request.
        model (str):
            Which model to select for the given request. Select the
            model best suited to your domain to get best results. If a
            model is not explicitly specified, then we auto-select a
            model based on the parameters in the RecognitionConfig.

            .. raw:: html

                <table>
                  <tr>
                    <td><b>Model</b></td>
                    <td><b>Description</b></td>
                  </tr>
                  <tr>
                    <td><code>latest_long</code></td>
                    <td>Best for long form content like media or conversation.</td>
                  </tr>
                  <tr>
                    <td><code>latest_short</code></td>
                    <td>Best for short form content like commands or single shot directed
                    speech.</td>
                  </tr>
                  <tr>
                    <td><code>command_and_search</code></td>
                    <td>Best for short queries such as voice commands or voice search.</td>
                  </tr>
                  <tr>
                    <td><code>phone_call</code></td>
                    <td>Best for audio that originated from a phone call (typically
                    recorded at an 8khz sampling rate).</td>
                  </tr>
                  <tr>
                    <td><code>video</code></td>
                    <td>Best for audio that originated from video or includes multiple
                        speakers. Ideally the audio is recorded at a 16khz or greater
                        sampling rate. This is a premium model that costs more than the
                        standard rate.</td>
                  </tr>
                  <tr>
                    <td><code>default</code></td>
                    <td>Best for audio that is not one of the specific audio models.
                        For example, long-form audio. Ideally the audio is high-fidelity,
                        recorded at a 16khz or greater sampling rate.</td>
                  </tr>
                  <tr>
                    <td><code>medical_conversation</code></td>
                    <td>Best for audio that originated from a conversation between a
                        medical provider and patient.</td>
                  </tr>
                  <tr>
                    <td><code>medical_dictation</code></td>
                    <td>Best for audio that originated from dictation notes by a medical
                        provider.</td>
                  </tr>
                </table>
        use_enhanced (bool):
            Set to true to use an enhanced model for speech recognition.
            If ``use_enhanced`` is set to true and the ``model`` field
            is not set, then an appropriate enhanced model is chosen if
            an enhanced model exists for the audio.

            If ``use_enhanced`` is true and an enhanced version of the
            specified model does not exist, then the speech is
            recognized using the standard version of the specified
            model.
    """

    class AudioEncoding(proto.Enum):
        r"""The encoding of the audio data sent in the request.

        All encodings support only 1 channel (mono) audio, unless the
        ``audio_channel_count`` and
        ``enable_separate_recognition_per_channel`` fields are set.

        For best results, the audio source should be captured and
        transmitted using a lossless encoding (``FLAC`` or ``LINEAR16``).
        The accuracy of the speech recognition can be reduced if lossy
        codecs are used to capture or transmit audio, particularly if
        background noise is present. Lossy codecs include ``MULAW``,
        ``AMR``, ``AMR_WB``, ``OGG_OPUS``, ``SPEEX_WITH_HEADER_BYTE``,
        ``MP3``, and ``WEBM_OPUS``.

        The ``FLAC`` and ``WAV`` audio file formats include a header that
        describes the included audio content. You can request recognition
        for ``WAV`` files that contain either ``LINEAR16`` or ``MULAW``
        encoded audio. If you send ``FLAC`` or ``WAV`` audio file format in
        your request, you do not need to specify an ``AudioEncoding``; the
        audio encoding format is determined from the file header. If you
        specify an ``AudioEncoding`` when you send send ``FLAC`` or ``WAV``
        audio, the encoding configuration must match the encoding described
        in the audio header; otherwise the request returns an
        [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]
        error code.
        """
        ENCODING_UNSPECIFIED = 0
        LINEAR16 = 1
        FLAC = 2
        MULAW = 3
        AMR = 4
        AMR_WB = 5
        OGG_OPUS = 6
        SPEEX_WITH_HEADER_BYTE = 7
        MP3 = 8
        WEBM_OPUS = 9

    encoding = proto.Field(
        proto.ENUM,
        number=1,
        enum=AudioEncoding,
    )
    sample_rate_hertz = proto.Field(
        proto.INT32,
        number=2,
    )
    audio_channel_count = proto.Field(
        proto.INT32,
        number=7,
    )
    enable_separate_recognition_per_channel = proto.Field(
        proto.BOOL,
        number=12,
    )
    language_code = proto.Field(
        proto.STRING,
        number=3,
    )
    alternative_language_codes = proto.RepeatedField(
        proto.STRING,
        number=18,
    )
    max_alternatives = proto.Field(
        proto.INT32,
        number=4,
    )
    profanity_filter = proto.Field(
        proto.BOOL,
        number=5,
    )
    adaptation = proto.Field(
        proto.MESSAGE,
        number=20,
        message=resource.SpeechAdaptation,
    )
    transcript_normalization = proto.Field(
        proto.MESSAGE,
        number=24,
        message=resource.TranscriptNormalization,
    )
    speech_contexts = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message="SpeechContext",
    )
    enable_word_time_offsets = proto.Field(
        proto.BOOL,
        number=8,
    )
    enable_word_confidence = proto.Field(
        proto.BOOL,
        number=15,
    )
    enable_automatic_punctuation = proto.Field(
        proto.BOOL,
        number=11,
    )
    enable_spoken_punctuation = proto.Field(
        proto.MESSAGE,
        number=22,
        message=wrappers_pb2.BoolValue,
    )
    enable_spoken_emojis = proto.Field(
        proto.MESSAGE,
        number=23,
        message=wrappers_pb2.BoolValue,
    )
    enable_speaker_diarization = proto.Field(
        proto.BOOL,
        number=16,
    )
    diarization_speaker_count = proto.Field(
        proto.INT32,
        number=17,
    )
    diarization_config = proto.Field(
        proto.MESSAGE,
        number=19,
        message="SpeakerDiarizationConfig",
    )
    metadata = proto.Field(
        proto.MESSAGE,
        number=9,
        message="RecognitionMetadata",
    )
    model = proto.Field(
        proto.STRING,
        number=13,
    )
    use_enhanced = proto.Field(
        proto.BOOL,
        number=14,
    )


class SpeakerDiarizationConfig(proto.Message):
    r"""Config to enable speaker diarization.

    Attributes:
        enable_speaker_diarization (bool):
            If 'true', enables speaker detection for each recognized
            word in the top alternative of the recognition result using
            a speaker_tag provided in the WordInfo.
        min_speaker_count (int):
            Minimum number of speakers in the
            conversation. This range gives you more
            flexibility by allowing the system to
            automatically determine the correct number of
            speakers. If not set, the default value is 2.
        max_speaker_count (int):
            Maximum number of speakers in the
            conversation. This range gives you more
            flexibility by allowing the system to
            automatically determine the correct number of
            speakers. If not set, the default value is 6.
        speaker_tag (int):
            Output only. Unused.
    """

    enable_speaker_diarization = proto.Field(
        proto.BOOL,
        number=1,
    )
    min_speaker_count = proto.Field(
        proto.INT32,
        number=2,
    )
    max_speaker_count = proto.Field(
        proto.INT32,
        number=3,
    )
    speaker_tag = proto.Field(
        proto.INT32,
        number=5,
    )


class RecognitionMetadata(proto.Message):
    r"""Description of audio data to be recognized.

    Attributes:
        interaction_type (google.cloud.speech_v1p1beta1.types.RecognitionMetadata.InteractionType):
            The use case most closely describing the
            audio content to be recognized.
        industry_naics_code_of_audio (int):
            The industry vertical to which this speech
            recognition request most closely applies. This
            is most indicative of the topics contained in
            the audio.  Use the 6-digit NAICS code to
            identify the industry vertical - see
            https://www.naics.com/search/.
        microphone_distance (google.cloud.speech_v1p1beta1.types.RecognitionMetadata.MicrophoneDistance):
            The audio type that most closely describes
            the audio being recognized.
        original_media_type (google.cloud.speech_v1p1beta1.types.RecognitionMetadata.OriginalMediaType):
            The original media the speech was recorded
            on.
        recording_device_type (google.cloud.speech_v1p1beta1.types.RecognitionMetadata.RecordingDeviceType):
            The type of device the speech was recorded
            with.
        recording_device_name (str):
            The device used to make the recording.
            Examples 'Nexus 5X' or 'Polycom SoundStation IP
            6000' or 'POTS' or 'VoIP' or 'Cardioid
            Microphone'.
        original_mime_type (str):
            Mime type of the original audio file. For example
            ``audio/m4a``, ``audio/x-alaw-basic``, ``audio/mp3``,
            ``audio/3gpp``. A list of possible audio mime types is
            maintained at
            http://www.iana.org/assignments/media-types/media-types.xhtml#audio
        obfuscated_id (int):
            Obfuscated (privacy-protected) ID of the
            user, to identify number of unique users using
            the service.
        audio_topic (str):
            Description of the content. Eg. "Recordings
            of federal supreme court hearings from 2012".
    """

    class InteractionType(proto.Enum):
        r"""Use case categories that the audio recognition request can be
        described by.
        """
        INTERACTION_TYPE_UNSPECIFIED = 0
        DISCUSSION = 1
        PRESENTATION = 2
        PHONE_CALL = 3
        VOICEMAIL = 4
        PROFESSIONALLY_PRODUCED = 5
        VOICE_SEARCH = 6
        VOICE_COMMAND = 7
        DICTATION = 8

    class MicrophoneDistance(proto.Enum):
        r"""Enumerates the types of capture settings describing an audio
        file.
        """
        MICROPHONE_DISTANCE_UNSPECIFIED = 0
        NEARFIELD = 1
        MIDFIELD = 2
        FARFIELD = 3

    class OriginalMediaType(proto.Enum):
        r"""The original media the speech was recorded on."""
        ORIGINAL_MEDIA_TYPE_UNSPECIFIED = 0
        AUDIO = 1
        VIDEO = 2

    class RecordingDeviceType(proto.Enum):
        r"""The type of device the speech was recorded with."""
        RECORDING_DEVICE_TYPE_UNSPECIFIED = 0
        SMARTPHONE = 1
        PC = 2
        PHONE_LINE = 3
        VEHICLE = 4
        OTHER_OUTDOOR_DEVICE = 5
        OTHER_INDOOR_DEVICE = 6

    interaction_type = proto.Field(
        proto.ENUM,
        number=1,
        enum=InteractionType,
    )
    industry_naics_code_of_audio = proto.Field(
        proto.UINT32,
        number=3,
    )
    microphone_distance = proto.Field(
        proto.ENUM,
        number=4,
        enum=MicrophoneDistance,
    )
    original_media_type = proto.Field(
        proto.ENUM,
        number=5,
        enum=OriginalMediaType,
    )
    recording_device_type = proto.Field(
        proto.ENUM,
        number=6,
        enum=RecordingDeviceType,
    )
    recording_device_name = proto.Field(
        proto.STRING,
        number=7,
    )
    original_mime_type = proto.Field(
        proto.STRING,
        number=8,
    )
    obfuscated_id = proto.Field(
        proto.INT64,
        number=9,
    )
    audio_topic = proto.Field(
        proto.STRING,
        number=10,
    )


class SpeechContext(proto.Message):
    r"""Provides "hints" to the speech recognizer to favor specific
    words and phrases in the results.

    Attributes:
        phrases (Sequence[str]):
            A list of strings containing words and phrases "hints" so
            that the speech recognition is more likely to recognize
            them. This can be used to improve the accuracy for specific
            words and phrases, for example, if specific commands are
            typically spoken by the user. This can also be used to add
            additional words to the vocabulary of the recognizer. See
            `usage
            limits <https://cloud.google.com/speech-to-text/quotas#content>`__.

            List items can also be set to classes for groups of words
            that represent common concepts that occur in natural
            language. For example, rather than providing phrase hints
            for every month of the year, using the $MONTH class improves
            the likelihood of correctly transcribing audio that includes
            months.
        boost (float):
            Hint Boost. Positive value will increase the probability
            that a specific phrase will be recognized over other similar
            sounding phrases. The higher the boost, the higher the
            chance of false positive recognition as well. Negative boost
            values would correspond to anti-biasing. Anti-biasing is not
            enabled, so negative boost will simply be ignored. Though
            ``boost`` can accept a wide range of positive values, most
            use cases are best served with values between 0 and 20. We
            recommend using a binary search approach to finding the
            optimal value for your use case.
    """

    phrases = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    boost = proto.Field(
        proto.FLOAT,
        number=4,
    )


class RecognitionAudio(proto.Message):
    r"""Contains audio data in the encoding specified in the
    ``RecognitionConfig``. Either ``content`` or ``uri`` must be
    supplied. Supplying both or neither returns
    [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT].
    See `content
    limits <https://cloud.google.com/speech-to-text/quotas#content>`__.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        content (bytes):
            The audio data bytes encoded as specified in
            ``RecognitionConfig``. Note: as with all bytes fields, proto
            buffers use a pure binary representation, whereas JSON
            representations use base64.

            This field is a member of `oneof`_ ``audio_source``.
        uri (str):
            URI that points to a file that contains audio data bytes as
            specified in ``RecognitionConfig``. The file must not be
            compressed (for example, gzip). Currently, only Google Cloud
            Storage URIs are supported, which must be specified in the
            following format: ``gs://bucket_name/object_name`` (other
            URI formats return
            [google.rpc.Code.INVALID_ARGUMENT][google.rpc.Code.INVALID_ARGUMENT]).
            For more information, see `Request
            URIs <https://cloud.google.com/storage/docs/reference-uris>`__.

            This field is a member of `oneof`_ ``audio_source``.
    """

    content = proto.Field(
        proto.BYTES,
        number=1,
        oneof="audio_source",
    )
    uri = proto.Field(
        proto.STRING,
        number=2,
        oneof="audio_source",
    )


class RecognizeResponse(proto.Message):
    r"""The only message returned to the client by the ``Recognize`` method.
    It contains the result as zero or more sequential
    ``SpeechRecognitionResult`` messages.

    Attributes:
        results (Sequence[google.cloud.speech_v1p1beta1.types.SpeechRecognitionResult]):
            Sequential list of transcription results
            corresponding to sequential portions of audio.
        total_billed_time (google.protobuf.duration_pb2.Duration):
            When available, billed audio seconds for the
            corresponding request.
    """

    results = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="SpeechRecognitionResult",
    )
    total_billed_time = proto.Field(
        proto.MESSAGE,
        number=3,
        message=duration_pb2.Duration,
    )


class LongRunningRecognizeResponse(proto.Message):
    r"""The only message returned to the client by the
    ``LongRunningRecognize`` method. It contains the result as zero or
    more sequential ``SpeechRecognitionResult`` messages. It is included
    in the ``result.response`` field of the ``Operation`` returned by
    the ``GetOperation`` call of the ``google::longrunning::Operations``
    service.

    Attributes:
        results (Sequence[google.cloud.speech_v1p1beta1.types.SpeechRecognitionResult]):
            Sequential list of transcription results
            corresponding to sequential portions of audio.
        total_billed_time (google.protobuf.duration_pb2.Duration):
            When available, billed audio seconds for the
            corresponding request.
        output_config (google.cloud.speech_v1p1beta1.types.TranscriptOutputConfig):
            Original output config if present in the
            request.
        output_error (google.rpc.status_pb2.Status):
            If the transcript output fails this field
            contains the relevant error.
    """

    results = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="SpeechRecognitionResult",
    )
    total_billed_time = proto.Field(
        proto.MESSAGE,
        number=3,
        message=duration_pb2.Duration,
    )
    output_config = proto.Field(
        proto.MESSAGE,
        number=6,
        message="TranscriptOutputConfig",
    )
    output_error = proto.Field(
        proto.MESSAGE,
        number=7,
        message=status_pb2.Status,
    )


class LongRunningRecognizeMetadata(proto.Message):
    r"""Describes the progress of a long-running ``LongRunningRecognize``
    call. It is included in the ``metadata`` field of the ``Operation``
    returned by the ``GetOperation`` call of the
    ``google::longrunning::Operations`` service.

    Attributes:
        progress_percent (int):
            Approximate percentage of audio processed
            thus far. Guaranteed to be 100 when the audio is
            fully processed and the results are available.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Time when the request was received.
        last_update_time (google.protobuf.timestamp_pb2.Timestamp):
            Time of the most recent processing update.
        uri (str):
            Output only. The URI of the audio file being
            transcribed. Empty if the audio was sent as byte
            content.
        output_config (google.cloud.speech_v1p1beta1.types.TranscriptOutputConfig):
            Output only. A copy of the
            TranscriptOutputConfig if it was set in the
            request.
    """

    progress_percent = proto.Field(
        proto.INT32,
        number=1,
    )
    start_time = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    last_update_time = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    uri = proto.Field(
        proto.STRING,
        number=4,
    )
    output_config = proto.Field(
        proto.MESSAGE,
        number=5,
        message="TranscriptOutputConfig",
    )


class StreamingRecognizeResponse(proto.Message):
    r"""``StreamingRecognizeResponse`` is the only message returned to the
    client by ``StreamingRecognize``. A series of zero or more
    ``StreamingRecognizeResponse`` messages are streamed back to the
    client. If there is no recognizable audio, and ``single_utterance``
    is set to false, then no messages are streamed back to the client.

    Here's an example of a series of ``StreamingRecognizeResponse``\ s
    that might be returned while processing audio:

    1. results { alternatives { transcript: "tube" } stability: 0.01 }

    2. results { alternatives { transcript: "to be a" } stability: 0.01
       }

    3. results { alternatives { transcript: "to be" } stability: 0.9 }
       results { alternatives { transcript: " or not to be" } stability:
       0.01 }

    4. results { alternatives { transcript: "to be or not to be"
       confidence: 0.92 } alternatives { transcript: "to bee or not to
       bee" } is_final: true }

    5. results { alternatives { transcript: " that's" } stability: 0.01
       }

    6. results { alternatives { transcript: " that is" } stability: 0.9
       } results { alternatives { transcript: " the question" }
       stability: 0.01 }

    7. results { alternatives { transcript: " that is the question"
       confidence: 0.98 } alternatives { transcript: " that was the
       question" } is_final: true }

    Notes:

    -  Only two of the above responses #4 and #7 contain final results;
       they are indicated by ``is_final: true``. Concatenating these
       together generates the full transcript: "to be or not to be that
       is the question".

    -  The others contain interim ``results``. #3 and #6 contain two
       interim ``results``: the first portion has a high stability and
       is less likely to change; the second portion has a low stability
       and is very likely to change. A UI designer might choose to show
       only high stability ``results``.

    -  The specific ``stability`` and ``confidence`` values shown above
       are only for illustrative purposes. Actual values may vary.

    -  In each response, only one of these fields will be set:
       ``error``, ``speech_event_type``, or one or more (repeated)
       ``results``.

    Attributes:
        error (google.rpc.status_pb2.Status):
            If set, returns a [google.rpc.Status][google.rpc.Status]
            message that specifies the error for the operation.
        results (Sequence[google.cloud.speech_v1p1beta1.types.StreamingRecognitionResult]):
            This repeated list contains zero or more results that
            correspond to consecutive portions of the audio currently
            being processed. It contains zero or one ``is_final=true``
            result (the newly settled portion), followed by zero or more
            ``is_final=false`` results (the interim results).
        speech_event_type (google.cloud.speech_v1p1beta1.types.StreamingRecognizeResponse.SpeechEventType):
            Indicates the type of speech event.
        total_billed_time (google.protobuf.duration_pb2.Duration):
            When available, billed audio seconds for the
            stream. Set only if this is the last response in
            the stream.
    """

    class SpeechEventType(proto.Enum):
        r"""Indicates the type of speech event."""
        SPEECH_EVENT_UNSPECIFIED = 0
        END_OF_SINGLE_UTTERANCE = 1

    error = proto.Field(
        proto.MESSAGE,
        number=1,
        message=status_pb2.Status,
    )
    results = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="StreamingRecognitionResult",
    )
    speech_event_type = proto.Field(
        proto.ENUM,
        number=4,
        enum=SpeechEventType,
    )
    total_billed_time = proto.Field(
        proto.MESSAGE,
        number=5,
        message=duration_pb2.Duration,
    )


class StreamingRecognitionResult(proto.Message):
    r"""A streaming speech recognition result corresponding to a
    portion of the audio that is currently being processed.

    Attributes:
        alternatives (Sequence[google.cloud.speech_v1p1beta1.types.SpeechRecognitionAlternative]):
            May contain one or more recognition hypotheses (up to the
            maximum specified in ``max_alternatives``). These
            alternatives are ordered in terms of accuracy, with the top
            (first) alternative being the most probable, as ranked by
            the recognizer.
        is_final (bool):
            If ``false``, this ``StreamingRecognitionResult`` represents
            an interim result that may change. If ``true``, this is the
            final time the speech service will return this particular
            ``StreamingRecognitionResult``, the recognizer will not
            return any further hypotheses for this portion of the
            transcript and corresponding audio.
        stability (float):
            An estimate of the likelihood that the recognizer will not
            change its guess about this interim result. Values range
            from 0.0 (completely unstable) to 1.0 (completely stable).
            This field is only provided for interim results
            (``is_final=false``). The default of 0.0 is a sentinel value
            indicating ``stability`` was not set.
        result_end_time (google.protobuf.duration_pb2.Duration):
            Time offset of the end of this result
            relative to the beginning of the audio.
        channel_tag (int):
            For multi-channel audio, this is the channel number
            corresponding to the recognized result for the audio from
            that channel. For audio_channel_count = N, its output values
            can range from '1' to 'N'.
        language_code (str):
            Output only. The
            `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
            language tag of the language in this result. This language
            code was detected to have the most likelihood of being
            spoken in the audio.
    """

    alternatives = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="SpeechRecognitionAlternative",
    )
    is_final = proto.Field(
        proto.BOOL,
        number=2,
    )
    stability = proto.Field(
        proto.FLOAT,
        number=3,
    )
    result_end_time = proto.Field(
        proto.MESSAGE,
        number=4,
        message=duration_pb2.Duration,
    )
    channel_tag = proto.Field(
        proto.INT32,
        number=5,
    )
    language_code = proto.Field(
        proto.STRING,
        number=6,
    )


class SpeechRecognitionResult(proto.Message):
    r"""A speech recognition result corresponding to a portion of the
    audio.

    Attributes:
        alternatives (Sequence[google.cloud.speech_v1p1beta1.types.SpeechRecognitionAlternative]):
            May contain one or more recognition hypotheses (up to the
            maximum specified in ``max_alternatives``). These
            alternatives are ordered in terms of accuracy, with the top
            (first) alternative being the most probable, as ranked by
            the recognizer.
        channel_tag (int):
            For multi-channel audio, this is the channel number
            corresponding to the recognized result for the audio from
            that channel. For audio_channel_count = N, its output values
            can range from '1' to 'N'.
        result_end_time (google.protobuf.duration_pb2.Duration):
            Time offset of the end of this result
            relative to the beginning of the audio.
        language_code (str):
            Output only. The
            `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
            language tag of the language in this result. This language
            code was detected to have the most likelihood of being
            spoken in the audio.
    """

    alternatives = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="SpeechRecognitionAlternative",
    )
    channel_tag = proto.Field(
        proto.INT32,
        number=2,
    )
    result_end_time = proto.Field(
        proto.MESSAGE,
        number=4,
        message=duration_pb2.Duration,
    )
    language_code = proto.Field(
        proto.STRING,
        number=5,
    )


class SpeechRecognitionAlternative(proto.Message):
    r"""Alternative hypotheses (a.k.a. n-best list).

    Attributes:
        transcript (str):
            Transcript text representing the words that
            the user spoke. In languages that use spaces to
            separate words, the transcript might have a
            leading space if it isn't the first result. You
            can concatenate each result to obtain the full
            transcript without using a separator.
        confidence (float):
            The confidence estimate between 0.0 and 1.0. A higher number
            indicates an estimated greater likelihood that the
            recognized words are correct. This field is set only for the
            top alternative of a non-streaming result or, of a streaming
            result where ``is_final=true``. This field is not guaranteed
            to be accurate and users should not rely on it to be always
            provided. The default of 0.0 is a sentinel value indicating
            ``confidence`` was not set.
        words (Sequence[google.cloud.speech_v1p1beta1.types.WordInfo]):
            A list of word-specific information for each recognized
            word. Note: When ``enable_speaker_diarization`` is true, you
            will see all the words from the beginning of the audio.
    """

    transcript = proto.Field(
        proto.STRING,
        number=1,
    )
    confidence = proto.Field(
        proto.FLOAT,
        number=2,
    )
    words = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="WordInfo",
    )


class WordInfo(proto.Message):
    r"""Word-specific information for recognized words.

    Attributes:
        start_time (google.protobuf.duration_pb2.Duration):
            Time offset relative to the beginning of the audio, and
            corresponding to the start of the spoken word. This field is
            only set if ``enable_word_time_offsets=true`` and only in
            the top hypothesis. This is an experimental feature and the
            accuracy of the time offset can vary.
        end_time (google.protobuf.duration_pb2.Duration):
            Time offset relative to the beginning of the audio, and
            corresponding to the end of the spoken word. This field is
            only set if ``enable_word_time_offsets=true`` and only in
            the top hypothesis. This is an experimental feature and the
            accuracy of the time offset can vary.
        word (str):
            The word corresponding to this set of
            information.
        confidence (float):
            The confidence estimate between 0.0 and 1.0. A higher number
            indicates an estimated greater likelihood that the
            recognized words are correct. This field is set only for the
            top alternative of a non-streaming result or, of a streaming
            result where ``is_final=true``. This field is not guaranteed
            to be accurate and users should not rely on it to be always
            provided. The default of 0.0 is a sentinel value indicating
            ``confidence`` was not set.
        speaker_tag (int):
            Output only. A distinct integer value is assigned for every
            speaker within the audio. This field specifies which one of
            those speakers was detected to have spoken this word. Value
            ranges from '1' to diarization_speaker_count. speaker_tag is
            set if enable_speaker_diarization = 'true' and only in the
            top alternative.
    """

    start_time = proto.Field(
        proto.MESSAGE,
        number=1,
        message=duration_pb2.Duration,
    )
    end_time = proto.Field(
        proto.MESSAGE,
        number=2,
        message=duration_pb2.Duration,
    )
    word = proto.Field(
        proto.STRING,
        number=3,
    )
    confidence = proto.Field(
        proto.FLOAT,
        number=4,
    )
    speaker_tag = proto.Field(
        proto.INT32,
        number=5,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
